@@ -171,7 +171,7 @@ def setup(settings_path=None, **settings_patches):
     beanstalk_apache_conf = render_file(
         beanstalk_apache_conf_template, beanstalk_settings, BEANSTALK_APP_APACHE_CONF=apache_conf_path())
     with open('/etc/httpd/conf.d/beanstalk.conf', 'w') as f:
-        f.read(beanstalk_apache_conf)
+        f.write(beanstalk_apache_conf)
     local('echo "# Beanstalk Apache conf" > %s' % apache_conf_path())
     local('chown beanstalk:beanstalk %s' % apache_conf_path())
 
